from easypost.resource import (
    AllResource,
    CreateResource,
    NextPageResource,
)


class Insurance(AllResource, CreateResource, NextPageResource):
    pass
